charport-package: charport: ALTREP String Interoperability

charport-packageR Documentation

charport: ALTREP String Interoperability

Description

logo

Provides infrastructure for interoperable ALTREP character vectors. Producers of ALTREP string classes can register access methods, allowing consumers to read supported character vectors through a common interface without materializing them as ordinary R strings. Also provides 'charvec', a reference ALTREP string implementation backed by stable memory slices, with support for efficient and multithreaded construction.

Author(s)

Maintainer: Travers Ching traversc@gmail.com [copyright holder]

Authors:

Other contributors:

  • R Consortium (Infrastructure Steering Committee grant: Universal ALTREP Interoperability for Strings) [funder]

See Also

Useful links:


charport documentation built on Sept. 21, 2026, 5:09 p.m.