| charport-package | R Documentation |
Provides infrastructure for interoperable ALTREP character vectors. Producers of ALTREP string classes can register access methods, allowing consumers to read supported character vectors through a common interface without materializing them as ordinary R strings. Also provides 'charvec', a reference ALTREP string implementation backed by stable memory slices, with support for efficient and multithreaded construction.
Maintainer: Travers Ching traversc@gmail.com [copyright holder]
Authors:
Travers Ching traversc@gmail.com [copyright holder]
Other contributors:
R Consortium (Infrastructure Steering Committee grant: Universal ALTREP Interoperability for Strings) [funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.